# LAB 

**L**inear **A**lgebra **B**ackends: a lightweight interface for linear algebra engines.


**Current Backends**: [Numpy](https://numpy.org) and [PyTorch](https://pytorch.org).

**Planned Backends**: [CuPy](https://cupy.dev) and [JAX](https://github.com/google/jax).


